@@ -1,21 +1,6 @@
-/*
- * Copyright (C) 2017 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     jouyouyun <jouyouwen717@gmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 package brightness
 
@@ -286,6 +271,28 @@ func supportDDCCIBrightness(edidBase64 string) bool {
 	return res
 }
 
+// 如果有屏幕的增加，刷新一下DDCCI的display
+// ddcciHelper的RefreshDisplays 重新读取显示列表，所以屏幕拔出不需要触发此刷新
+// 由于RefreshDisplays 较慢，使用携程处理。
+func ReflashDDCCIDisplay() {
+	if helper == nil {
+		return
+	}
+	res, err := helper.CheckCfgSupport(0, "ddcci")
+	if err != nil {
+		logger.Warningf("brightness: failed to check ddc/ci support: %v", err)
+		return
+	}
+	if res {
+		logger.Debug("refresh ddcci display")
+		err = ddcciHelper.RefreshDisplays(0)
+		if err != nil {
+			logger.Warningf("brightness: failed to refresh ddc/ci display list: %v", err)
+			return
+		}
+	}
+}
+
 func setDDCCIBrightness(value float64, edidBase64 string) error {
 	res, err := helper.CheckCfgSupport(0, "ddcci")
 	if err != nil {
