@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 package display
 
 import (
@@ -342,7 +346,6 @@ func newManager(service *dbusutil.Service) *Manager {
 			m.newSysCfg = nil
 		}
 
-		m.handleTouchscreenChanged()
 		m.showTouchscreenDialogs()
 
 		// 监听用户的session Active属性改变信号，当切换到当前已经登录的用户时
@@ -1265,7 +1268,8 @@ func (m *Manager) addMonitor(monitorInfo *MonitorInfo) error {
 		logger.Warning("call SetWriteCallback err:", err)
 		return err
 	}
-
+	// 如果屏幕添加，刷新一下ddcci的display列表
+	go brightness.ReflashDDCCIDisplay()
 	return nil
 }
 
@@ -1529,8 +1533,11 @@ func (m *Manager) handlePrimaryRectChanged(pmi *MonitorInfo) {
 	m.PropsMu.Lock()
 	defer m.PropsMu.Unlock()
 
-	m.setPropPrimary(pmi.Name)
-	m.setPropPrimaryRect(pmi.getRect())
+	// 复制模式不用设置主屏
+	if m.DisplayMode != DisplayModeMirror {
+		m.setPropPrimary(pmi.Name)
+		m.setPropPrimaryRect(pmi.getRect())
+	}
 }
 
 func (m *Manager) setPrimary(name string) error {
