@@ -1,21 +1,6 @@
-/*
- * Copyright (C) 2014 ~ 2018 Deepin Technology Co., Ltd.
- *
- * Author:     jouyouyun <jouyouwen717@gmail.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2018 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 package main
 
@@ -41,6 +26,7 @@ import (
 	ofdbus "github.com/linuxdeepin/go-dbus-factory/org.freedesktop.dbus"
 	login1 "github.com/linuxdeepin/go-dbus-factory/org.freedesktop.login1"
 	systemd1 "github.com/linuxdeepin/go-dbus-factory/org.freedesktop.systemd1"
+	xeventmonitor "github.com/linuxdeepin/go-dbus-factory/com.deepin.api.xeventmonitor"
 	gio "github.com/linuxdeepin/go-gir/gio-2.0"
 	"github.com/linuxdeepin/go-lib/appinfo/desktopappinfo"
 	"github.com/linuxdeepin/go-lib/dbusutil"
@@ -641,6 +627,7 @@ func newSessionManager(service *dbusutil.Service) *SessionManager {
 	// 如果其它进程读取了非法的属性值， dbus连接会被关闭，导致startdde启动失败
 	m.initSession()
 	m.init()
+	go initXEventMonitor()
 
 	return m
 }
@@ -1389,3 +1376,17 @@ func setDpmsModeByKwin(mode int32) {
 
 	return
 }
+
+func initXEventMonitor() {
+	bus, _ := dbus.SessionBus()
+	xEvent := xeventmonitor.NewXEventMonitor(bus)
+	sigLoop := dbusutil.NewSignalLoop(bus, 1)
+	sigLoop.Start()
+	xEvent.InitSignalExt(sigLoop, true)
+	xEvent.ConnectButtonPress(func(button int32, x int32, y int32, id string) {
+		// 5表示鼠标中间
+		if button == 5 {
+			setDPMSMode(true)
+		}
+	})
+}
\ No newline at end of file
